/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License;
 * you may not use this file except in compliance with the Elastic License.
 */

import { callWithRequestFactory } from '../../../lib/call_with_request_factory';
import { isEsErrorFactory } from '../../../lib/is_es_error_factory';
import { wrapEsError, wrapUnknownError } from '../../../lib/error_wrappers';
import { licensePreRoutingFactory } from'../../../lib/license_pre_routing_factory';

async function forcemergeIndices(callWithRequest, indices, maxNumSegments) {
  const params = {
    expandWildcards: 'none',
    index: indices,
  };
  if (maxNumSegments) {
    params.max_num_segments = maxNumSegments;
  }

  return await callWithRequest('indices.forcemerge', params);
}

export function registerForcemergeRoute(server) {
  const isEsError = isEsErrorFactory(server);
  const licensePreRouting = licensePreRoutingFactory(server);

  server.route({
    path: '/api/index_management/indices/forcemerge',
    method: 'POST',
    handler: async (request, h) => {
      const callWithRequest = callWithRequestFactory(server, request);
      const { payload } = request;
      const { indices = [], maxNumSegments } = payload;
      try {
        await forcemergeIndices(callWithRequest, indices, maxNumSegments);

        //TODO: Should we check acknowledged = true?
        return h.response();
      } catch (err) {
        if (isEsError(err)) {
          throw wrapEsError(err);
        }

        throw wrapUnknownError(err);
      }
    },
    config: {
      pre: [ licensePreRouting ]
    }
  });
}
