/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License;
 * you may not use this file except in compliance with the Elastic License.
 */
import {
  EuiButton,
  EuiCallOut,
  EuiFlexGroup,
  EuiFlexItem,
  EuiPageBody,
  EuiPageContent,
  EuiPageContentBody,
} from '@elastic/eui';
import React from 'react';
import styled from 'styled-components';

import { FlexPage } from './page';

interface Props {
  detailedMessage?: React.ReactNode;
  retry?: () => void;
  shortMessage: React.ReactNode;
}

export const ErrorPage: React.SFC<Props> = ({ detailedMessage, retry, shortMessage }) => (
  <FlexPage>
    <EuiPageBody>
      <MinimumPageContent
        horizontalPosition="center"
        verticalPosition="center"
        panelPaddingSize="none"
      >
        <EuiPageContentBody>
          <EuiCallOut color="danger" iconType="cross" title="An error occurred">
            <EuiFlexGroup>
              <EuiFlexItem>{shortMessage}</EuiFlexItem>
              {retry ? (
                <EuiFlexItem grow={false}>
                  <EuiButton onClick={retry} iconType="refresh">
                    Try again
                  </EuiButton>
                </EuiFlexItem>
              ) : null}
            </EuiFlexGroup>
            {detailedMessage ? <div>{detailedMessage}</div> : null}
          </EuiCallOut>
        </EuiPageContentBody>
      </MinimumPageContent>
    </EuiPageBody>
  </FlexPage>
);

const MinimumPageContent = styled(EuiPageContent)`
  min-width: 50vh;
`;
